@@ -3,7 +3,7 @@
 #-------------------------------------------------------------------------------
 """Base setuptools command for tests."""
 __author__ = ('Lance Finn Helsten',)
-__version__ = '0.2'
+__version__ = '0.3'
 __copyright__ = """Copyright (C) 2014 Lance Helsten"""
 __docformat__ = "reStructuredText en"
 __license__ = """
@@ -141,7 +141,8 @@ class TestBase(SetupTest):
                 for dirpath, dirnames, filenames in os.walk(os.environ["VIRTUAL_ENV"]):
                     omit.append(os.path.join(dirpath, '*.py'))
 
-            datafile = os.path.join(self.build_base, self.test_type) + "_coverage"
+            datafile = os.path.join(self.build_base, "coverage_data", self.test_type)
+            os.makedirs(os.path.dirname(datafile), exist_ok=True)
             self.cov = coverage.coverage(data_file=datafile, data_suffix=True, branch=True, config_file=True, omit=omit)
         else:
             self.cov = NoCoverage()
